#
# spec file for package azure-cli
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%if 0%{?suse_version} >= 1600
%define pythons %{primary_python}
%else
%define pythons python311
%endif
%global _sitelibdir %{%{pythons}_sitelib}

# Define just "test" as a package in _multibuild file to distinguish test
# instructions here
%if "" == ""
%define _test 0
%define name_ext %nil
%else
%define _test 1
%define name_ext -test
%endif

%if !%{?_test}
Name:           azure-cli
%else
Name:           azure-cli%{?name_ext}
%endif
%define         short_name azure-cli
Version:        2.63.0
Release:        1.1
Summary:        Microsoft Azure CLI 2.0
License:        MIT
Group:          System/Management
URL:            https://github.com/Azure/azure-cli
Source:         https://files.pythonhosted.org/packages/source/a/azure-cli/azure_cli-%{version}.tar.gz
Patch1:         ac_use-python3-by-default.patch
%if 0%{?_test}
BuildRequires:  %{short_name} = %{version}
%else
BuildRequires:  %{pythons}-pip
BuildRequires:  %{pythons}-wheel
BuildRequires:  azure-cli-core = %{version}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       %{pythons}-Fabric >= 3.2.2
Requires:       %{pythons}-PyGithub >= 1.38
Requires:       %{pythons}-PyNaCl >= 1.5.0
Requires:       %{pythons}-PyYAML >= 5.1
Requires:       %{pythons}-antlr4-python3-runtime >= 4.13.1
Requires:       %{pythons}-azure-appconfiguration >= 1.1.1
Requires:       %{pythons}-azure-batch >= 14.2.0
Requires:       %{pythons}-azure-cosmos >= 3.0.2
Requires:       %{pythons}-azure-data-tables >= 12.4.0
Requires:       %{pythons}-azure-datalake-store >= 0.0.53
Requires:       %{pythons}-azure-graphrbac >= 0.60.0
Requires:       %{pythons}-azure-keyvault-administration >= 4.4.0~b2
Requires:       %{pythons}-azure-keyvault-certificates >= 4.7.0
Requires:       %{pythons}-azure-keyvault-keys >= 4.9.0~b3
Requires:       %{pythons}-azure-keyvault-secrets >= 4.7.0
Requires:       %{pythons}-azure-mgmt-advisor >= 9.0.0
Requires:       %{pythons}-azure-mgmt-apimanagement >= 4.0.0
Requires:       %{pythons}-azure-mgmt-appconfiguration >= 3.0.0
Requires:       %{pythons}-azure-mgmt-appcontainers >= 2.0.0
Requires:       %{pythons}-azure-mgmt-applicationinsights >= 1.0.0
Requires:       %{pythons}-azure-mgmt-authorization >= 4.0.0
Requires:       %{pythons}-azure-mgmt-batch >= 17.3.0
Requires:       %{pythons}-azure-mgmt-batchai >= 7.0.0b1
Requires:       %{pythons}-azure-mgmt-billing >= 6.0.0
Requires:       %{pythons}-azure-mgmt-botservice >= 2.0.0b3
Requires:       %{pythons}-azure-mgmt-cdn >= 12.0.0
Requires:       %{pythons}-azure-mgmt-cognitiveservices >= 13.5.0
Requires:       %{pythons}-azure-mgmt-compute >= 31.0.0
Requires:       %{pythons}-azure-mgmt-containerinstance >= 10.1.0
Requires:       %{pythons}-azure-mgmt-containerregistry >= 10.3.0
Requires:       %{pythons}-azure-mgmt-containerservice >= 31.0.0
Requires:       %{pythons}-azure-mgmt-cosmosdb >= 9.5.1
Requires:       %{pythons}-azure-mgmt-databoxedge >= 1.0.0
Requires:       %{pythons}-azure-mgmt-datamigration >= 10.0.0
Requires:       %{pythons}-azure-mgmt-devtestlabs >= 2.2
Requires:       %{pythons}-azure-mgmt-dns >= 8.0.0
Requires:       %{pythons}-azure-mgmt-eventgrid >= 10.2.0
Requires:       %{pythons}-azure-mgmt-eventhub >= 10.1.0
Requires:       %{pythons}-azure-mgmt-extendedlocation >= 1.0.0b2
Requires:       %{pythons}-azure-mgmt-hdinsight >= 9.0.0
Requires:       %{pythons}-azure-mgmt-imagebuilder >= 1.3.0
Requires:       %{pythons}-azure-mgmt-iotcentral >= 10.0.0b1
Requires:       %{pythons}-azure-mgmt-iothub >= 3.0.0
Requires:       %{pythons}-azure-mgmt-iothubprovisioningservices >= 1.1.0
Requires:       %{pythons}-azure-mgmt-keyvault >= 10.3.0
Requires:       %{pythons}-azure-mgmt-kusto >= 0.3.0
Requires:       %{pythons}-azure-mgmt-loganalytics >= 13.0.0
Requires:       %{pythons}-azure-mgmt-managedservices >= 1.0
Requires:       %{pythons}-azure-mgmt-managementgroups >= 1.0.0
Requires:       %{pythons}-azure-mgmt-maps >= 2.0.0
Requires:       %{pythons}-azure-mgmt-marketplaceordering >= 1.1.0
Requires:       %{pythons}-azure-mgmt-media >= 9.0
Requires:       %{pythons}-azure-mgmt-monitor >= 5.0.0
Requires:       %{pythons}-azure-mgmt-msi >= 7.0.0
Requires:       %{pythons}-azure-mgmt-netapp >= 10.1.0
Requires:       %{pythons}-azure-mgmt-policyinsights >= 1.1.0b4
Requires:       %{pythons}-azure-mgmt-privatedns >= 1.0.0
Requires:       %{pythons}-azure-mgmt-rdbms >= 10.2.0b16
Requires:       %{pythons}-azure-mgmt-recoveryservices >= 3.0.0
Requires:       %{pythons}-azure-mgmt-recoveryservicesbackup >= 9.1.0
Requires:       %{pythons}-azure-mgmt-redhatopenshift >= 1.4.0
Requires:       %{pythons}-azure-mgmt-redis >= 14.3.0
Requires:       %{pythons}-azure-mgmt-reservations >= 2.0.0
Requires:       %{pythons}-azure-mgmt-resource >= 23.1.1
Requires:       %{pythons}-azure-mgmt-search >= 9.0
Requires:       %{pythons}-azure-mgmt-security >= 6.0.0
Requires:       %{pythons}-azure-mgmt-servicebus >= 8.2.0
Requires:       %{pythons}-azure-mgmt-servicefabric >= 2.1.0
Requires:       %{pythons}-azure-mgmt-servicefabricmanagedclusters >= 2.0.0~b6
Requires:       %{pythons}-azure-mgmt-servicelinker >= 1.2.0~b2
Requires:       %{pythons}-azure-mgmt-signalr >= 2.0.0~b1
Requires:       %{pythons}-azure-mgmt-sql >= 4.0.0b17
Requires:       %{pythons}-azure-mgmt-sqlvirtualmachine >= 1.0.0b5
Requires:       %{pythons}-azure-mgmt-storage >= 21.2.0
Requires:       %{pythons}-azure-mgmt-synapse >= 2.1.0b5
Requires:       %{pythons}-azure-mgmt-trafficmanager >= 1.0.0
Requires:       %{pythons}-azure-mgmt-web >= 7.2.0
Requires:       %{pythons}-azure-monitor-query >= 1.2.0
Requires:       %{pythons}-azure-multiapi-storage >= 1.2.0
Requires:       %{pythons}-azure-storage-common >= 1.4
Requires:       %{pythons}-azure-synapse-accesscontrol >= 0.5.0
Requires:       %{pythons}-azure-synapse-artifacts >= 0.19.0
Requires:       %{pythons}-azure-synapse-managedprivateendpoints >= 0.4.0
Requires:       %{pythons}-azure-synapse-spark >= 0.2.0
Requires:       %{pythons}-chardet >= 5.2.0
Requires:       %{pythons}-colorama >= 0.4.4
Requires:       %{pythons}-distro
Requires:       %{pythons}-javaproperties >= 0.5.1
Requires:       %{pythons}-jsondiff >= 2.0.0
Requires:       %{pythons}-packaging >= 20.9
Requires:       %{pythons}-pycomposefile >= 0.0.29
Requires:       %{pythons}-pygments >= 2.4
Requires:       %{pythons}-scp >= 0.13.2
Requires:       %{pythons}-semver >= 2.13.0
Requires:       %{pythons}-six >= 1.10.0
Requires:       %{pythons}-sshtunnel >= 0.1.4
Requires:       %{pythons}-tabulate
Requires:       %{pythons}-urllib3
Requires:       %{pythons}-websocket-client >= 1.3.1
Requires:       %{pythons}-xmltodict >= 0.12
Requires:       azure-cli-core = %{version}
Provides:       azure-cli-acr = 2.2.9
Obsoletes:      azure-cli-acr < 2.2.9
Provides:       azure-cli-acs = 2.4.4
Obsoletes:      azure-cli-acs < 2.4.4
Provides:       azure-cli-advisor = 2.0.1
Obsoletes:      azure-cli-advisor < 2.0.1
Provides:       azure-cli-ams = 0.4.7
Obsoletes:      azure-cli-ams < 0.4.7
Provides:       azure-cli-appservice = 0.2.21
Obsoletes:      azure-cli-appservice < 0.2.21
Provides:       azure-cli-backup = 1.2.5
Obsoletes:      azure-cli-backup < 1.2.5
Provides:       azure-cli-batch = 4.0.3
Obsoletes:      azure-cli-batch < 4.0.3
Provides:       azure-cli-batchai = 0.4.10
Obsoletes:      azure-cli-batchai < 0.4.10
Provides:       azure-cli-billing = 0.2.2
Obsoletes:      azure-cli-billing < 0.2.2
Provides:       azure-cli-botservice = 0.2.2
Obsoletes:      azure-cli-botservice < 0.2.2
Provides:       azure-cli-cdn = 0.2.4
Obsoletes:      azure-cli-cdn < 0.2.4
Provides:       azure-cli-cloud = 2.1.1
Obsoletes:      azure-cli-cloud < 2.1.1
Provides:       azure-cli-cognitiveservices = 0.2.6
Obsoletes:      azure-cli-cognitiveservices < 0.2.6
Provides:       azure-cli-component = 2.0.8
Obsoletes:      azure-cli-component < 2.0.8
Provides:       azure-cli-configure = 2.0.24
Obsoletes:      azure-cli-configure < 2.0.24
Provides:       azure-cli-consumption = 0.4.4
Obsoletes:      azure-cli-consumption < 0.4.4
Provides:       azure-cli-container = 0.3.18
Obsoletes:      azure-cli-container < 0.3.18
Provides:       azure-cli-cosmosdb = 0.2.11
Obsoletes:      azure-cli-cosmosdb < 0.2.11
Provides:       azure-cli-deploymentmanager = 0.1.1
Obsoletes:      azure-cli-deploymentmanager < 0.1.1
Provides:       azure-cli-dla = 0.2.6
Obsoletes:      azure-cli-dla < 0.2.6
Provides:       azure-cli-dls = 0.1.10
Obsoletes:      azure-cli-dls < 0.1.10
Provides:       azure-cli-dms = 0.1.4
Obsoletes:      azure-cli-dms < 0.1.4
Provides:       azure-cli-eventgrid = 0.2.4
Obsoletes:      azure-cli-eventgrid < 0.2.4
Provides:       azure-cli-eventhubs = 0.3.7
Obsoletes:      azure-cli-eventhubs < 0.3.7
Provides:       azure-cli-extension = 0.2.5
Obsoletes:      azure-cli-extension < 0.2.5
Provides:       azure-cli-feedback = 2.2.1
Obsoletes:      azure-cli-feedback < 2.2.1
Provides:       azure-cli-find = 0.3.4
Obsoletes:      azure-cli-find < 0.3.4
Provides:       azure-cli-hdinsight = 0.3.5
Obsoletes:      azure-cli-hdinsight < 0.3.5
Provides:       azure-cli-interactive = 0.4.5
Obsoletes:      azure-cli-interactive < 0.4.5
Provides:       azure-cli-iot = 0.3.11
Obsoletes:      azure-cli-iot < 0.3.11
Provides:       azure-cli-iotcentral = 0.1.7
Obsoletes:      azure-cli-iotcentral < 0.1.7
Provides:       azure-cli-keyvault = 2.2.16
Obsoletes:      azure-cli-keyvault < 2.2.16
Provides:       azure-cli-kusto = 0.2.3
Obsoletes:      azure-cli-kusto < 0.2.3
Provides:       azure-cli-lab = 0.1.8
Obsoletes:      azure-cli-lab < 0.1.8
Provides:       azure-cli-maps = 0.3.5
Obsoletes:      azure-cli-maps < 0.3.5
Provides:       azure-cli-monitor = 0.2.15
Obsoletes:      azure-cli-monitor < 0.2.15
Provides:       azure-cli-natgateway = 0.1.1
Obsoletes:      azure-cli-natgateway < 0.1.1
Provides:       azure-cli-network = 2.5.2
Obsoletes:      azure-cli-network < 2.5.2
Provides:       azure-cli-policyinsights = 0.1.4
Obsoletes:      azure-cli-policyinsights < 0.1.4
Provides:       azure-cli-privatedns = 1.0.2
Obsoletes:      azure-cli-privatedns < 1.0.2
Provides:       azure-cli-profile = 2.1.5
Obsoletes:      azure-cli-profile < 2.1.5
Provides:       azure-cli-rdbms = 0.3.12
Obsoletes:      azure-cli-rdbms < 0.3.12
Provides:       azure-cli-redis = 0.4.4
Obsoletes:      azure-cli-redis < 0.4.4
Provides:       azure-cli-relay = 0.1.5
Obsoletes:      azure-cli-relay < 0.1.5
Provides:       azure-cli-reservations = 0.4.3
Obsoletes:      azure-cli-reservations < 0.4.3
Provides:       azure-cli-resource = 2.1.16
Obsoletes:      azure-cli-resource < 2.1.16
Provides:       azure-cli-role = 2.6.4
Obsoletes:      azure-cli-role < 2.6.4
Provides:       azure-cli-search = 0.1.2
Obsoletes:      azure-cli-search < 0.1.2
Provides:       azure-cli-security = 0.1.2
Obsoletes:      azure-cli-security < 0.1.2
Provides:       azure-cli-servicebus = 0.3.6
Obsoletes:      azure-cli-servicebus < 0.3.6
Provides:       azure-cli-servicefabric = 0.1.20
Obsoletes:      azure-cli-servicefabric < 0.1.20
Provides:       azure-cli-signalr = 1.0.1
Obsoletes:      azure-cli-signalr < 1.0.1
Provides:       azure-cli-sql = 2.2.5
Obsoletes:      azure-cli-sql < 2.2.5
Provides:       azure-cli-sqlvm = 0.2.0
Obsoletes:      azure-cli-sqlvm < 0.2.0
Provides:       azure-cli-storage = 2.4.3
Obsoletes:      azure-cli-storage < 2.4.3
Provides:       azure-cli-vm = 2.2.23
Obsoletes:      azure-cli-vm < 2.2.23
Conflicts:      azure-cli < 2.0.0

BuildArch:      noarch
%endif

%description
Microsoft Azure CLI 2.0 Command Line Utilities

%prep
%if 0%{?_test}
# workaround to prevent post/install failing assuming this file for whatever
# reason
touch %{_sourcedir}/%{short_name}
%else
%setup -q -n azure_cli-%{version}
%patch -P 1 -p1
%endif

%build
%if 0%{?_test}
set +x
for i in $(az | sed -n 's/\s*\([a-z,-]*\)\s\+\:.*/\1/p') ; do
    echo -n "Testing $i command .. "
    if az $i --help > /dev/null 2>&1 ; then
	echo "OK"
    else
	echo "FAIL"
    fi
done
set -x
%else
%pyproject_wheel
%endif

%install
%if 0%{?_test}
# disable debug packages in package test to prevent error about missing files
%define debug_package %{nil}
%else
%pyproject_install
install -DTm644 %{buildroot}%{_bindir}/az.completion.sh %{buildroot}%{_datadir}/bash-completion/completions/az
%fdupes %{buildroot}%{_sitelibdir}
%endif

%files
%if !%{?_test}
%defattr(-,root,root,-)
%doc HISTORY.rst README.rst
%license LICENSE.txt
%{_bindir}/az
%{_datadir}/bash-completion/completions/az
%exclude /usr/bin/az.bat
%exclude /usr/bin/az.completion.sh
%exclude /usr/bin/azps.ps1
%{_sitelibdir}/azure/cli
%{_sitelibdir}/azure_cli-*.dist-info
%endif

%changelog
* Wed Aug  7 2024 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 2.63.0
  + For detailed information about changes see the
    HISTORY.rst file provided with this package
- Drop extra LICENSE.txt as upstream now ships its own
- Update Requires from setup.py
* Tue Jul  9 2024 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 2.62.0
  + For detailed information about changes see the
    HISTORY.rst file provided with this package
- Update Requires from setup.py
* Wed May 22 2024 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 2.61.0
  + For detailed information about changes see the
    HISTORY.rst file provided with this package
- Remove deletion of azure-cli namespace files
- Remove deletion of azure-cli-command-modules namespace files
- Update BuildRequires and Requires from setup.py
* Mon May  6 2024 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 2.60.0
  + For detailed information about changes see the
    HISTORY.rst file provided with this package
- Adjust upstream source name in spec file
- Update Requires from setup.py
* Tue Apr  9 2024 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 2.59.0
  + For detailed information about changes see the
    HISTORY.rst file provided with this package
- Update Requires from setup.py
* Thu Apr  4 2024 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Switch package to modern Python Stack on SLE-15
  + Use Python 3.11 on SLE-15 by default
  + Use primary Python version on Tumbleweed
- Switch build system from setuptools to pyproject.toml
  + Add python-pip and python-wheel to BuildRequires
  + Replace %%python_build with %%pyproject_wheel
  + Replace %%python_install with %%pyproject_install
  + Update name for dist directory in %%files section
* Wed Mar  6 2024 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 2.58.0
  + For detailed information about changes see the
    HISTORY.rst file provided with this package
- Update Requires from setup.py
* Tue Feb 20 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%patch -P N instead of deprecated %%patchN.
* Wed Feb  7 2024 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 2.57.0
  + For detailed information about changes see the
    HISTORY.rst file provided with this package
- Update Requires from setup.py
* Thu Jan 18 2024 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 2.56.0
  + For detailed information about changes see the
    HISTORY.rst file provided with this package
- Update Requires from setup.py
* Wed Jan  3 2024 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 2.55.0
  + For detailed information about changes see the
    HISTORY.rst file provided with this package
- Update Requires from setup.py
* Wed Nov 15 2023 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 2.54.0
  + For detailed information about changes see the
    HISTORY.rst file provided with this package
- Update Requires from setup.py
* Mon Oct 30 2023 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 2.53.1
  + For detailed information about changes see the
    HISTORY.rst file provided with this package
* Wed Oct  4 2023 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 2.53.0
  + For detailed information about changes see the
    HISTORY.rst file provided with this package
- Update Requires from setup.py
* Thu Sep  7 2023 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 2.52.0
  + For detailed information about changes see the
    HISTORY.rst file provided with this package
- Update Requires from setup.py
* Mon Aug 14 2023 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 2.51.0
  + For detailed information about changes see the
    HISTORY.rst file provided with this package
- Update Requires from setup.py
* Thu Jul  6 2023 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 2.50.0
  + For detailed information about changes see the
    HISTORY.rst file provided with this package
- Update Requires from setup.py
* Wed May 24 2023 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 2.49.0
  + For detailed information about changes see the
    HISTORY.rst file provided with this package
- Update Requires from setup.py
* Wed May  3 2023 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 2.48.1
  + For detailed information about changes see the
    HISTORY.rst file provided with this package
- Update Requires from setup.py
* Tue Apr  4 2023 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 2.47.0
  + For detailed information about changes see the
    HISTORY.rst file provided with this package
- Update Requires from setup.py
* Tue Mar  7 2023 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release (bsc#1199592)
  + Version 2.46.0
  + For detailed information about changes see the
    HISTORY.rst file provided with this package
- Update Requires from setup.py
* Thu Feb  9 2023 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 2.45.0
  + For detailed information about changes see the
    HISTORY.rst file provided with this package
- Update Requires from setup.py
* Wed Jan 18 2023 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 2.44.1
  + For detailed information about changes see the
    HISTORY.rst file provided with this package
* Tue Jan 10 2023 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 2.44.0
  + For detailed information about changes see the
    HISTORY.rst file provided with this package
- Update Requires from setup.py
* Tue Dec  6 2022 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 2.43.0
  + For detailed information about changes see the
    HISTORY.rst file provided with this package
- Update Requires from setup.py
* Tue Nov  1 2022 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 2.42.0
  + For detailed information about changes see the
    HISTORY.rst file provided with this package
- Update Requires from setup.py
* Thu Oct 13 2022 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 2.41.0
  + For detailed information about changes see the
    HISTORY.rst file provided with this package
- Rename %%exclude az.ps1 to azps.ps1 in %%files section
- Update Requires from setup.py
* Fri Sep 16 2022 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 2.40.0
  + For detailed information about changes see the
    HISTORY.rst file provided with this package
- Add %%exclude for newly added az.ps1 in %%files section
- Update Requires from setup.py
* Thu Aug  4 2022 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 2.39.0
  + For detailed information about changes see the
    HISTORY.rst file provided with this package
- Update Requires from setup.py
* Tue Jul  5 2022 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 2.38.0
  + For detailed information about changes see the
    HISTORY.rst file provided with this package
- Update Requires from setup.py
* Tue May 24 2022 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 2.37.0
  + For detailed information about changes see the
    HISTORY.rst file provided with this package
- Update Requires from setup.py
* Tue Apr 26 2022 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 2.36.0
  + For detailed information about changes see the
    HISTORY.rst file provided with this package
- Update Requires from setup.py
* Tue Apr 12 2022 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 2.35.0
  + For detailed information about changes see the
    HISTORY.rst file provided with this package
- Update Requires from setup.py
* Mon Mar  7 2022 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 2.34.1
  + For detailed information about changes see the
    HISTORY.rst file provided with this package
- Update Requires from setup.py
* Wed Feb 23 2022 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 2.33.1
  + For detailed information about changes see the
    HISTORY.rst file provided with this package
* Fri Feb 11 2022 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 2.33.0
  + For detailed information about changes see the
    HISTORY.rst file provided with this package
- Add missing python-rpm-macros to BuildRequires
- Update Requires from setup.py
* Mon Jan 10 2022 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 2.32.0
  + For detailed information about changes see the
    HISTORY.rst file provided with this package
- Update Requires from setup.py
* Tue Dec  7 2021 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 2.31.0
  + For detailed information about changes see the
    HISTORY.rst file provided with this package
- Update Requires from setup.py
* Mon Nov  8 2021 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 2.30.0
  + For detailed information about changes see the
    HISTORY.rst file provided with this package
- Extend %%check section to test individual az commands
  + Determine current list of available az commands
  + Ignore sub-commands for now
  + Iterate over all commands and run az --help
  + Print OK or FAIL depending on the result for each call
  + Make failures non-fatal for now
- Update Requires from setup.py
* Fri Oct 15 2021 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 2.29.0
  + For detailed information about changes see the
    HISTORY.rst file provided with this package
- Update Requires from setup.py
* Fri Sep 10 2021 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 2.28.1
  + For detailed information about changes see the
    HISTORY.rst file provided with this package
- Update Requires from setup.py
* Wed Aug 25 2021 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 2.27.2
  + For detailed information about changes see the
    HISTORY.rst file provided with this package
- Update Requires from setup.py
* Fri Aug  6 2021 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 2.27.0
  + For detailed information about changes see the
    HISTORY.rst file provided with this package
- Update Requires from setup.py
* Tue Jul 13 2021 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 2.26.0
  + For detailed information about changes see the
    HISTORY.rst file provided with this package
- Update Requires from setup.py
* Thu Jul  1 2021 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release (bsc#1187881)
  + Version 2.25.0
  + For detailed information about changes see the
    HISTORY.rst file provided with this package
- Update Requires from setup.py
* Wed Jun  9 2021 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 2.24.2
  + For detailed information about changes see the
    HISTORY.rst file provided with this package
- Update Requires from setup.py
* Mon May 10 2021 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 2.23.0
  + For detailed information about changes see the
    HISTORY.rst file provided with this package
- Update Requires from setup.py
* Mon Mar 29 2021 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 2.21.0
  + For detailed information about changes see the
    HISTORY.rst file provided with this package
- Update Requires from setup.py
* Thu Jan 21 2021 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 2.18.0
  + For detailed information about changes see the
    HISTORY.rst file provided with this package
- Update Requires from setup.py
* Fri Jan  8 2021 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 2.17.1
  + For detailed information about changes see the
    HISTORY.rst file provided with this package
- Update Requires from setup.py
* Wed Dec 16 2020 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 2.16.0
  + For detailed information about changes see the
    HISTORY.rst file provided with this package
- Update Requires from setup.py
* Wed Nov 18 2020 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 2.15.0
  + For detailed information about changes see the
    HISTORY.rst file provided with this package
- Update Requires from setup.py
* Mon Nov 16 2020 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 2.14.2
  + For detailed information about changes see the
    HISTORY.rst file provided with this package
- Remove bogus dependencies from BuildRequires
- Update Requires from setup.py
* Mon Nov  2 2020 olaf@aepfle.de
- Remove trailing .sh suffix from bash-completion to make sure
  az is actually recognized as a command with completions
  Drop also the string 'completion' from resulting filename
* Tue Oct 13 2020 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 2.13.0
  + For detailed information about changes see the
    HISTORY.rst file provided with this package
- Update BuildRequires and Requires from setup.py
* Wed Sep 30 2020 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 2.12.1
  + For detailed information about changes see the
    HISTORY.rst file provided with this package
* Tue Sep 22 2020 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release (bsc#1176784, bsc#1176785)
  + Version 2.12.0
  + For detailed information about changes see the
    HISTORY.rst file provided with this package
- Update BuildRequires and Requires from setup.py
* Mon Aug 31 2020 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 2.11.1
  + For detailed information about changes see the
    HISTORY.rst file provided with this package
- Set version dependency for azure-cli-core to %%{version}
- Update BuildRequires and Requires from setup.py
* Tue Aug 18 2020 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release (boo#1175289)
  + Version 2.10.1
  + For detailed information about changes see the
    HISTORY.rst file provided with this package
- Update BuildRequires and Requires from setup.py
* Mon Jul 20 2020 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 2.9.1
  + For detailed information about changes see the
    HISTORY.rst file provided with this package
- Update BuildRequires and Requires from setup.py
* Wed Jun 17 2020 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 2.7.0
  + For detailed information about changes see the
    HISTORY.rst file provided with this package
- Update BuildRequires and Requires from setup.py
* Thu May  7 2020 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 2.5.1
  + For detailed information about changes see the
    HISTORY.rst file provided with this package
- Update BuildRequires and Requires from setup.py
* Thu Apr  2 2020 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 2.3.1
  + For detailed information about changes see the
    HISTORY.rst file provided with this package
- Update BuildRequires and Requires from setup.py
* Tue Mar 10 2020 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 2.2.0
  + For detailed information about changes see the
    HISTORY.rst file provided with this package
- Update BuildRequires and Requires from setup.py
* Mon Feb 24 2020 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 2.1.0
  + For detailed information about changes see the
    HISTORY.rst file provided with this package
- Update BuildRequires and Requires from setup.py
* Thu Jan 16 2020 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 2.0.80
  + For detailed information about changes see the
    HISTORY.rst file provided with this package
- Update BuildRequires and Requires from setup.py
* Tue Jan  7 2020 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 2.0.79
  + For detailed information about changes see the
    HISTORY.rst file provided with this package
- Update BuildRequires and Requires from setup.py
* Mon Jan  6 2020 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 2.0.78
  + For detailed information about changes see the
    HISTORY.rst file provided with this package
- Update BuildRequires and Requires from setup.py
* Tue Dec  3 2019 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Remove namespace files provided by azure-cli-command-modules-nspkg
* Thu Nov 28 2019 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 2.0.77
  + For detailed information about changes see the
    HISTORY.rst file provided with this package
- Consolidate azure-cli command module packages into single
  azure-cli package
  + Add Provides and Obsoletes for consolidated packages
  + Stop deleting command modules from build tree in %%install section
- Update BuildRequires and Requires from setup.py
* Thu Oct 24 2019 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 2.0.75 (boo#1154393)
  + For detailed information about changes see the
    HISTORY.rst file provided with this package
- Add additional azure-cli component packages to Requires
  + azure-cli-deploymentmanager
  + azure-cli-natgateway
  + azure-cli-privatedns
- Remove command_modules in %%install section as these
  are installed as separate RPM packages
- Update Requires from setup.py
* Tue Jun  4 2019 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Remove unneccesary %%python_expand prefix from %%fdupes call
* Tue Apr 16 2019 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 2.0.58
  + For detailed information about changes see the
    HISTORY.rst file provided with this package
- Add additional azure-cli component packages to Requires
  + azure-cli-botservice
  + azure-cli-hdinsight
  + azure-cli-iotcentral
  + azure-cli-kusto
  + azure-cli-maps
  + azure-cli-policyinsights
  + azure-cli-relay
  + azure-cli-security
  + azure-cli-signalr
  + azure-cli-sqlvm
- Bump minimum version for Python Azure SDK namespace
  packages to 3.0.0 in BuildRequires and Requires
- Move /etc/bash_completion.d/az.completion.sh to
  %%{_datadir}/bash-completion/completions/
- Remove python3-devel package from BuildRequires
- Remove unzip package from BuildRequires
- Run fdupes to hardlink duplicate files
  + Add fdupes to BuildRequires
  + Add %%fdupes invocation to %%install
- Update Requires from setup.py
* Wed Nov 21 2018 okurz@suse.com
- Add multibuild package self-test
* Wed Nov 14 2018 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Add additional azure-cli component packages to Requires
  + azure-cli-command-modules-nspkg
  + azure-cli-component
  + azure-cli-taskhelp
  + azure-cli-telemetry
* Mon Oct  1 2018 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 2.0.45
  + For detailed information about changes see the
    HISTORY.rst file provided with this package
- Update Requires from setup.py
* Mon Apr 23 2018 adrian.glaubitz@suse.com
- New upstream release
  + Version 2.0.31
- Move LICENSE.txt from %%doc to %%license section
- Update Requires from setup.py
* Thu Feb  8 2018 adrian.glaubitz@suse.com
- New upstream release
  + Version 2.0.26
  + For detailed information about changes see the
    HISTORY.rst file provided with this package
- Install HISTORY.rst into doc directory
- Update Requires from setup.py
* Wed Sep 27 2017 adrian.glaubitz@suse.com
- Initial build
  + Version 2.0.18
- Include patch to set python3 as the default python
  interpretor for the "az" command
  + ac_use-python3-by-default.patch
